Load simuation results that were saved in sqlite data bases in one or multiple save folders when running SWAT.
load_swat_run(
save_dir,
variable = NULL,
run = NULL,
add_parameter = TRUE,
add_date = TRUE
)Character string or vector of character strings that provide the path/s to the save folder/s.
Output variables that were saved in the SWAT run and that should be loaded into R
Numeric vector giving the indexes of the simulations that should be loaded
Logical. If add_parameter = TRUE the parameter
set for the SWAT runs is added to the loaded data
Logical. If add_date = TRUE a date column is added to
the simulation results of each variable